%global pypi_name xmlschema
Name:           python-%{pypi_name}
Version:        3.4.5
Release:        1%{?dist}.1
Summary:        A Python XML Schema validator and decoder

License:        MIT
URL:            https://github.com/brunato/xmlschema
Source0:        https://files.pythonhosted.org/packages/source/x/%{pypi_name}/%{pypi_name}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros

%if 0%{?rhel} && 0%{?rhel} < 10
# RHEL 9 has too old version of tox
%bcond tests 0
%else
%bcond tests 1
%endif

%if %{with tests}
# tox -e py313 misses the lxml dependency
# when omitted, some tests are skipped
# https://github.com/sissaschool/xmlschema/issues/423
BuildRequires:  python3-lxml
%endif

%global _description %{expand:
The xmlschema library is an implementation of XML Schema for Python.

This library arises from the needs of a solid Python layer for processing XML
Schema based files for MaX (Materials design at the Exascale) European project.
A significant problem is the encoding and the decoding of the XML data files
produced by different simulation software. Another important requirement is
the XML data validation, in order to put the produced data under control.
The lack of a suitable alternative for Python in the schema-based decoding
of XML data has led to build this library. Obviously this library can be
useful for other cases related to XML Schema based processing, not only for
the original scope.}

%description %_description


%package -n     python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}  %_description


%prep
%autosetup -p1 -n %{pypi_name}-%{version}
sed -i 's/==/>=/' tox.ini  # too strict test deps
sed -i '/memory_profiler/d' tox.ini # optional test dep, not packaged in Fedora, not worth testing
%py3_shebang_fix %{pypi_name}

%generate_buildrequires
%if %{with tests}
%pyproject_buildrequires -t
%else
%pyproject_buildrequires
%endif

%build
%pyproject_wheel

%install
%pyproject_install

%if %{with tests}
%check
%tox
%endif

%files -n python3-%{pypi_name}
%license LICENSE
%doc README.rst
%{python3_sitelib}/%{pypi_name}/
%{python3_sitelib}/%{pypi_name}-%{version}.dist-info/
%{_bindir}/xmlschema-json2xml
%{_bindir}/xmlschema-validate
%{_bindir}/xmlschema-xml2json


%changelog
* Thu Jul 10 2025 Oleg Girko <ol@infoserver.lv> - 3.4.5-2
- Sync with version 3.4.5 from Fedora
- Disable tests on RHEL < 10 (tox is too old)
* Thu Sep  8 2022 Oleg Girko <ol@infoserver.lv> - 1.7.0-2
- Fix source URL for compatibility with OBS source services
* Wed Aug 18 2021 Charalampos Stratakis <cstratak@redhat.com> - 1.7.0-1
- Update to 1.7.0 (#1989154)
* Mon Jul 26 2021 Tomas Hrnciar <thrnciar@redhat.com> - 1.6.4-1
- Update to 1.6.4
* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
* Wed Jun  2 2021 Python Maint <python-maint@redhat.com> - 1.4.2-2
- Rebuilt for Python 3.10
* Thu Jan 28 2021 Tomas Hrnciar <thrnciar@redhat.com> - 1.4.2-1
- Update to 1.4.2
* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild
* Thu Jan 14 2021 Tomas Hrnciar <thrnciar@redhat.com> - 1.4.1-1
- Update to 1.4.1
* Mon Sep 21 2020 Lumír Balhar <lbalhar@redhat.com> - 1.0.18-5
- Fix FTBFS by build-requiring python3-devel
* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.18-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild
* Sat May 23 2020 Miro Hrončok <mhroncok@redhat.com> - 1.0.18-3
- Rebuilt for Python 3.9
* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.18-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild
* Tue Dec 31 2019 Miro Hrončok <mhroncok@redhat.com> - 1.0.18-1
- Update to 1.0.18
* Tue Dec 17 2019 Miro Hrončok <mhroncok@redhat.com> - 1.0.16-1
- Initial package
